@@ -35,10 +35,6 @@
 #include <gtkmm/main.h>
 #include <gtkmm/aboutdialog.h>
 
-#if HAVE_PANELAPPLET
-#include <panel-applet.h>
-#endif
-
 #include "gnote.hpp"
 #include "actionmanager.hpp"
 #include "addinmanager.hpp"
@@ -57,66 +53,17 @@
 #include "sharp/files.hpp"
 #include "synchronization/syncmanager.hpp"
 
-#if HAVE_PANELAPPLET
-#include "applet.hpp"
-#endif
-
 
 namespace gnote {
 
-  namespace {
-
-    typedef GtkApplicationClass GnoteAppClass;
-
-    G_DEFINE_TYPE(GnoteApp, gnote_app, GTK_TYPE_APPLICATION)
-
-    static void gnote_app_init(GnoteApp *)
-    {}
-
-    static void gnote_app_activate(GApplication *)
-    {
-      Gnote::obj().open_search_all();
-    }
-
-    static void gnote_app_startup(GApplication * application)
-    {
-      G_APPLICATION_CLASS(gnote_app_parent_class)->startup(application);
-      Gnote::obj().startup();
-    }
-
-    static int gnote_app_command_line(GApplication *, GApplicationCommandLine * command_line)
-    {
-      int argc;
-      char **argv = g_application_command_line_get_arguments(command_line, &argc);
-      return Gnote::obj().command_line(argc, argv);
-    }
-
-    static void gnote_app_class_init(GnoteAppClass * klass)
-    {
-      G_APPLICATION_CLASS(klass)->activate = gnote_app_activate;
-      G_APPLICATION_CLASS(klass)->startup = gnote_app_startup;
-      G_APPLICATION_CLASS(klass)->command_line = gnote_app_command_line;
-    }
-
-    GnoteApp * gnote_app_new()
-    {
-      g_type_init();
-      return static_cast<GnoteApp*>(g_object_new(gnote_app_get_type(),
-                                                 "application-id", "org.gnome.Gnote",
-                                                 "flags", G_APPLICATION_HANDLES_COMMAND_LINE,
-                                                 NULL));
-    }
-
-}
-
+  Gnote *Gnote::s_obj = NULL;
 
   Gnote::Gnote()
-    : m_manager(NULL)
+    : Gtk::Application("org.gnome.Gnote", Gio::APPLICATION_HANDLES_COMMAND_LINE)
+    , m_manager(NULL)
     , m_keybinder(NULL)
-    , m_is_panel_applet(false)
     , m_is_background(false)
     , m_prefsdlg(NULL)
-    , m_app(NULL)
   {
   }
 
@@ -136,10 +83,6 @@ namespace gnote {
         handle = true;
         break;
       }
-      else if(!strcmp(argv[i], "--panel-applet")) {
-        m_is_panel_applet = true;
-        break;
-      }
     }
 
     if(handle) {
@@ -148,38 +91,33 @@ namespace gnote {
       return 0;
     }
 
-    if(m_is_panel_applet) {
-#if HAVE_PANELAPPLET
-      common_init();
-      ActionManager & am(ActionManager::obj());
-      am["CloseWindowAction"]->set_visible(true);
-      am["QuitGNoteAction"]->set_visible(false);
-      register_remote_control(*m_manager, sigc::mem_fun(*this, &Gnote::end_main));
-      panel::register_applet();
-#endif
-    }
-    else {
-      m_app = gnote_app_new();
-      gdk_threads_enter();
-      g_application_run(G_APPLICATION(m_app), argc, argv);
-      gdk_threads_leave();
-      g_object_unref(m_app);
-      m_app = NULL;
-    }
+    int retval = run(argc, argv);
     signal_quit();
-    return 0;
+    return retval;
   }
 
 
-  void Gnote::startup()
+  void Gnote::on_startup()
   {
+    Gtk::Application::on_startup();
     m_icon_theme = Gtk::IconTheme::get_default();
     m_icon_theme->append_search_path(DATADIR"/icons");
     m_icon_theme->append_search_path(DATADIR"/gnote/icons");
   }
 
 
-  int Gnote::command_line(int argc, char **argv) {
+  void Gnote::on_activate()
+  {
+    Gtk::Application::on_activate();
+    open_search_all();
+  }
+
+
+  int Gnote::on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine> & command_line)
+  {
+    Gtk::Application::on_command_line(command_line);
+    int argc = 0;
+    char **argv = command_line->get_arguments(argc);
     cmd_line.parse(argc, argv);
     if(!m_manager) {
       common_init();
@@ -248,30 +186,26 @@ namespace gnote {
       }
     }
 
-    if(!m_is_panel_applet) {
-      Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
-        .get_schema_settings(Preferences::SCHEMA_GNOTE);
-      if(settings->get_boolean(Preferences::USE_STATUS_ICON)) {
-        DBG_OUT("starting tray icon");
-        start_tray_icon();
-      }
-      else if(m_is_background) {
-        // Create Search All Notes window as we need it present for application to run
-        NoteRecentChanges::get_instance(default_note_manager());
-      }
-      else {
-        am["ShowSearchAllNotesAction"]->activate();
-      }
+    Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
+      .get_schema_settings(Preferences::SCHEMA_GNOTE);
+    if(settings->get_boolean(Preferences::USE_STATUS_ICON)) {
+      DBG_OUT("starting tray icon");
+      start_tray_icon();
+    }
+    else if(m_is_background) {
+      // Create Search All Notes window as we need it present for application to run
+      NoteRecentChanges::get_instance(default_note_manager());
+    }
+    else {
+      am["ShowSearchAllNotesAction"]->activate();
     }
   }
 
 
   void Gnote::start_note_created(const Note::Ptr & start_note)
   {
-    DBG_OUT("we will show the start note: %d", !is_panel_applet());
-    if(!is_panel_applet()) {
-      start_note->get_window()->show();
-    }
+    DBG_OUT("we will show the start note");
+    start_note->get_window()->show();
   }
 
   std::string Gnote::get_note_path(const std::string & override_path)
@@ -379,14 +313,7 @@ namespace gnote {
 
   void Gnote::on_quit_gnote_action()
   {
-    if(m_is_panel_applet) {
-      return;
-    }
-#ifdef HAVE_GLIB_2_32
-    g_application_quit(G_APPLICATION(m_app));
-#else
-    Gtk::Main::quit();
-#endif
+    quit();
   }
 
   void Gnote::on_preferences_response(int /*res*/)
@@ -493,22 +420,6 @@ namespace gnote {
   }
 
 
-  void Gnote::add_window(Gtk::Window * window)
-  {
-    if(m_app) {
-      gtk_application_add_window(GTK_APPLICATION(m_app), GTK_WINDOW(window->gobj()));
-    }
-  }
-
-
-  void Gnote::remove_window(Gtk::Window * window)
-  {
-    if(m_app) {
-      gtk_application_remove_window(GTK_APPLICATION(m_app), GTK_WINDOW(window->gobj()));
-    }
-  }
-
-
   std::string Gnote::cache_dir()
   {
     return Glib::get_user_cache_dir() + "/gnote";
@@ -553,7 +464,6 @@ namespace gnote {
   {
     static const GOptionEntry entries[] =
       {
-        { "panel-applet", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &m_use_panel, _("Run Gnote as a GNOME panel applet."), NULL },
         { "background", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &m_background, _("Run Gnote in background."), NULL },
         { "note-path", 0, 0, G_OPTION_ARG_STRING, &m_note_path, _("Specify the path of the directory containing the notes."), _("path") },
         { "search", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK, (void*)GnoteCommandLine::parse_func, _("Open the search all notes window with the search text."), _("text") },
