@@ -40,7 +40,6 @@
 
 namespace gnote {
 
-typedef GtkApplication GnoteApp;
 class PreferencesDialog;
 class NoteManager;
 class RemoteControlClient;
@@ -59,10 +58,6 @@ public:
     }
   bool        needs_execute() const;
   bool        needs_immediate_execute() const;
-  bool        use_panel_applet() const
-    {
-      return m_use_panel;
-    }
   bool        background()
     {
       return m_background;
@@ -103,14 +98,21 @@ private:
 
 
 class Gnote
-  : public base::Singleton<Gnote>
+  : public Gtk::Application
 {
 public:
-  Gnote();
+  static Gnote& obj()
+    {
+      return *s_obj;
+    }
+  static Glib::RefPtr<Gnote> create()
+    {
+      s_obj = new Gnote;
+      return Glib::RefPtr<Gnote>(s_obj);
+    }
+
   ~Gnote();
   int main(int argc, char **argv);
-  void startup();
-  int command_line(int argc, char **argv);
   NoteManager & default_note_manager()
     {
       return *m_manager;
@@ -131,8 +133,6 @@ public:
   void on_show_about_action();
   void open_search_all();
   void open_note_sync_window();
-  void add_window(Gtk::Window * window);
-  void remove_window(Gtk::Window * window);
 
   static std::string cache_dir();
   static std::string conf_dir();
@@ -141,12 +141,7 @@ public:
 
   bool tray_icon_showing()
     {
-      return m_is_panel_applet
-             || (m_tray_icon && m_tray_icon->is_embedded() && m_tray_icon->get_visible());
-    }
-  bool is_panel_applet()
-    {
-      return m_is_panel_applet;
+      return m_tray_icon && m_tray_icon->is_embedded() && m_tray_icon->get_visible();
     }
   bool is_background() const
     {
@@ -167,7 +162,14 @@ public:
     {
       return m_sync_dlg;
     }
+protected:
+  virtual void on_activate();
+  virtual int on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine> & command_line);
+  virtual void on_startup();
 private:
+  static Gnote *s_obj;
+
+  Gnote();
   void start_note_created(const Note::Ptr & start_note);
   std::string get_note_path(const std::string & override_path);
   void on_setting_changed(const Glib::ustring & key);
@@ -180,11 +182,9 @@ private:
   Glib::RefPtr<Gtk::IconTheme> m_icon_theme;
   Glib::RefPtr<TrayIcon> m_tray_icon;
   Tray::Ptr m_tray;
-  bool m_is_panel_applet;
   bool m_is_background;
   PreferencesDialog *m_prefsdlg;
   GnoteCommandLine cmd_line;
-  GnoteApp *m_app;
   sync::SyncDialog::Ptr m_sync_dlg;
 };
 
