@@ -90,7 +90,7 @@ namespace gnote {
   }
 
   NoteRecentChanges::NoteRecentChanges(NoteManager& m)
-    : utils::ForcedPresentWindow(_("Search All Notes"))
+    : NoteRecentChangesParent(_("Search All Notes"))
     , m_manager(m)
     , m_menubar(NULL)
     , m_find_combo(Glib::RefPtr<Gtk::TreeModel>::cast_static(Gtk::ListStore::create(m_find_combo_columns)), true)
@@ -102,7 +102,7 @@ namespace gnote {
     , m_entry_changed_timeout(NULL)
     , m_clickX(0), m_clickY(0)
   {
-    Gnote::obj().add_window(this);
+    Gnote::obj().add_window(*this);
     _init_static();
 //    get_window()->set_icon_name("gnote");
     set_default_size(450,400);
@@ -239,10 +239,7 @@ namespace gnote {
 
   NoteRecentChanges::~NoteRecentChanges()
   {
-    if(m_entry_changed_timeout) {
-      delete m_entry_changed_timeout;
-    }
-    Gnote::obj().remove_window(this);
+    Gnote::obj().remove_window(*this);
   }
 
 
@@ -1251,7 +1248,7 @@ namespace gnote {
     select_all_notes_notebook ();
       
     m_find_combo.get_entry()->grab_focus ();
-    utils::ForcedPresentWindow::on_show();
+    NoteRecentChangesParent::on_show();
   }
 
   
